# SayHiHello

A simple demo project that has a `say_hello()` function which says hello!

# Building project

## Prerequisites

- conda

## Steps

1. Create a conda environment with python installed

```bash
conda env create -f environment.yml
conda activate sayhihello
```

2. Now use pip from the conda virtual environment to install `build` and `twine`.

```bash
which pip # this should show a location from inside the activate conda environment

pip install --upgrade build
pip install --upgrade twine
```

`build` is for building our package and `twine` is for uploading it

3. Build the project

```bash
python -m build
```

We should now see a `dist` directory created:

```bash
(sayhihello) ubaid@Mohammeds-MacBook-Pro sayhihello % ls -1  dist
sayhihello-0.0.1.1-py3-none-any.whl
sayhihello-0.0.1.1.tar.gz
```

4. Upload the built project

```bash
twine upload dist/*
```

You will need to provide it an API token. API tokens can be generated by going to your PyPi account at https://pypi.org/manage/account/ and under the "API tokens" heading.

The uploaded package can be found here https://pypi.org/project/sayhihello/.
